==> rtracklayer_1.16.3.tar.gz: rtracklayer/R/fasta.R <==
### =========================================================================
### FASTA support
### -------------------------------------------------------------------------
###
### Since we have 2bit, we might as well have FASTA
###

setClass("FastaFile", contains = "RTLFile")

FastaFile <- function(resource) {
  new("FastaFile", resource = resource)
}

### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
### Export
###

setMethod("export", c("ANY", "FastaFile"), function(object, con, ...) {
  export(as(object, "DNAStringSet"), con, ...)
})

setMethod("export", c("BSgenome", "FastaFile"),
          function(object, con, format, ...) {
            append <- FALSE
            for (seqname in seqnames(object)) {
              dna <- DNAStringSet(object[[seqname]])
              names(dna) <- seqname
              write.XStringSet(dna, path(con), append = append, ...)
              append <- TRUE
            }
          })

setMethod("export", c("XStringSet", "FastaFile"),
          function(object, con, format, ...)
          {
            write.XStringSet(object, path(con), format = "fasta", ...)
          })

### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
### Import
###

setMethod("import", "FastaFile",
          function(con, format, text, type = c("DNA", "RNA", "AA", "B"), ...)
          {
            if (!missing(format))
              checkArgFormat(con, format)
            readFun <- get(paste("read.", match.arg(type), "StringSet",
                                 sep = ""))
            readFun(path(con), format = "fasta", ...)
          })

==> rtracklayer_1.18.2.tar.gz: rtracklayer/R/fasta.R <==
### =========================================================================
### FASTA support
### -------------------------------------------------------------------------
###
### Since we have 2bit, we might as well have FASTA
###

setClass("FastaFile", contains = "RTLFile")

FastaFile <- function(resource) {
  new("FastaFile", resource = resource)
}

### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
### Export
###

setMethod("export", c("ANY", "FastaFile"), function(object, con, ...) {
  export(as(object, "DNAStringSet"), con, ...)
})

setMethod("export", c("BSgenome", "FastaFile"),
          function(object, con, format, ...) {
            append <- FALSE
            for (seqname in seqnames(object)) {
              dna <- object[[seqname]]
              masks(dna) <- NULL
              dna <- DNAStringSet(dna)
              names(dna) <- seqname
              writeXStringSet(dna, path(con), append = append, ...)
              append <- TRUE
            }
          })

setMethod("export", c("XStringSet", "FastaFile"),
          function(object, con, format, ...)
          {
            writeXStringSet(object, path(con), format = "fasta", ...)
          })

### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
### Import
###

setMethod("import", "FastaFile",
          function(con, format, text, type = c("DNA", "RNA", "AA", "B"), ...)
          {
            if (!missing(format))
              checkArgFormat(con, format)
            readFun <- get(paste("read.", match.arg(type), "StringSet",
                                 sep = ""))
            readFun(path(con), format = "fasta", ...)
          })
